$$QuantitySearchParametersTableOrderingComposer class
Constructors
- $$QuantitySearchParametersTableOrderingComposer({required _$FhirDb $db, required $QuantitySearchParametersTable $table, JoinBuilder? joinBuilder, void $addJoinBuilderToRootComposer(JoinBuilder)?, void $removeJoinBuilderFromRootComposer(JoinBuilder)?})
Properties
- $addJoinBuilderToRootComposer ↔ void Function(JoinBuilder)
-
A function to add a join builder to the root composer
latefinalinherited
- $db → _$FhirDb
-
The database instance used by the composer.
finalinherited
- $joinBuilder → JoinBuilder?
-
The
JoinBuilderused by the composer. If this composer wasn't created by a join, this will be null.finalinherited -
$joinBuilders
→ List<
JoinBuilder> -
If this composer is a root composer, this will contain all
the joinBuilders which any children may have created
finalinherited
- $removeJoinBuilderFromRootComposer ↔ void Function(JoinBuilder)
-
A function to remove a join builder from the root composer
This is used to remove join builders that are no longer needed.
e.g.
latefinalinherited
- $table → $QuantitySearchParametersTable
-
This current table being managed by the composer without any aliases applies.
Use
_aliasedTableto get the table with alias.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ ColumnOrderings<
String> -
no setter
-
lastUpdated
→ ColumnOrderings<
int> -
no setter
-
paramIndex
→ ColumnOrderings<
int> -
no setter
-
quantityCode
→ ColumnOrderings<
String> -
no setter
-
quantitySystem
→ ColumnOrderings<
String> -
no setter
-
quantityUnit
→ ColumnOrderings<
String> -
no setter
-
quantityValue
→ ColumnOrderings<
double> -
no setter
-
resourceType
→ ColumnOrderings<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchName
→ ColumnOrderings<
String> -
no setter
-
searchPath
→ ColumnOrderings<
String> -
no setter
Methods
-
$composableBuilder<
T, C extends GeneratedColumn< (Object> >{required C column, required T builder(C column)}) → T -
A helper method for creating composables that need
the correct aliases for the column and the join builders.
Every filter and ordering compasable is created using this method.
inherited
-
$composerBuilder<
T, CurrentColumn extends GeneratedColumn< (Object> , RelatedTable extends Table, RelatedColumn extends GeneratedColumn<Object> >{required Composer< GeneratedDatabase, Table> composer, required CurrentColumn getCurrentColumn($QuantitySearchParametersTable), required RelatedTable referencedTable, required RelatedColumn getReferencedColumn(RelatedTable), required T builder(JoinBuilder joinBuilder, {void $addJoinBuilderToRootComposer(JoinBuilder)?, void $removeJoinBuilderFromRootComposer(JoinBuilder)?})}) → T -
A helper method for creating related composers.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited